# -*- coding: utf-8 -*-
"""
Created on Sun Dec 10 17:15:23 2023

@author: Stacey.Yang
"""

from setuptools import setup, find_packages

setup(
    name='CRFActions',
    version='1.2',
    packages=find_packages(),  
    url='https://github.com/Doraemon-code/QianYang',
    author='Stacey',
    author_email='yq13408614660@163.com'
)